@@ -45,7 +45,7 @@ using std::uint64_t;
 using std::int32_t;
 
 
-#if defined(__GNUG__) || defined(__GNUC__) || defined(_MSC_VER) || defined(__clang__) || defined(__INTEL_COMPILER)
+#if defined(__GNUG__) || defined(__GNUC__) || defined(_MSC_VER) || defined(__clang__) || defined(__INTEL_COMPILER) || defined(SUPPORTS_RESTRICT)
 #   define restrict __restrict
 #else
 #   define restrict 
@@ -55,7 +55,7 @@ using std::int32_t;
 
 #if defined(_FOR_R)
 extern "C" double ddot_(const int *n, const double *dx, const int *incx, const double *dy, const int *incy);
-extern "C" double sdot_(const int *n, const float *dx, const int *incx, const float *dy, const int *incy);
+extern "C" float sdot_(const int *n, const float *dx, const int *incx, const float *dy, const int *incy);
 #endif
 
 #ifndef _FOR_R
